==> clickioconsent-1.0.1.tar.gz: clickioconsent/src/Form/ClickioCmpForm.php <==
<?php

namespace Drupal\clickioconsent\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines the configuration export form.
 */
class ClickioCmpForm extends ConfigFormBase {

  /**
   * The entity_type.bundle.info service.
   *
   * @var \Drupal\Core\Entity\EntityTypeBundleInfoInterface
   */
  protected $entityTypeBundleInfo;

  /**
   * The state service.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected $state;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    /**
     * @var \Drupal\clickioconsent\Form\ClickioCmpForm
     */
    $instance = parent::create($container);
    $instance->entityTypeBundleInfo = $container->get('entity_type.bundle.info');
//    $instance->metatagManager = $container->get('metatag.manager');
    $instance->state = $container->get('state');
//    $instance->tagPluginManager = $container->get('plugin.manager.metatag.tag');

    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'clickioconsent_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['clickioconsent.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    if ($this->state->get('system.maintenance_mode')) {
      $this->messenger()->addMessage($this->t('Please note that while the site is in maintenance mode none of the usual meta tags will be output.'));
    }


    $form['site_id'] = array(
      '#type' => 'number',
      '#title' => $this->t('Clickio Site ID'),
      '#default_value' => $this->config('clickioconsent.settings')->get('site_id') ?? 0,
      '#description' => $this->t('Place your <a href="https://docs.clickio.com/link/427#bkmrk-access-the-template%3A" target="_blank">Site ID from Clickio platform</a>.'),
    );

    $form['consent_enabled'] = array(
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Consent Mode support'),
      '#default_value' => $this->config('clickioconsent.settings')->get('consent_enabled') ?? TRUE,
      '#description' => $this->t('Allows this GTM template to automatically set <strong>default</strong> consent states and <strong>update</strong> consent states based on previous decisions made through Clickio CMP. This option functions correctly only when the "Consent Mode support" feature is activated in the Clickio Consent settings UI. Ensure this feature is enabled to properly synchronize consent management across your site. <a href="https://docs.clickio.com/link/427" target="_blank">Read more</a>'),
    );

    $form['range'] = array(
       '#type' => 'fieldset',
       '#collapsible' => TRUE,
       '#attributes' => [ 'style' => ['display:'.($this->config('clickioconsent.settings')->get('consent_enabled') === 0 ?'none':'block') ] ],
    );
//---- V
    $form['range']['scope'] = array(
      '#type' => 'radios',
      '#title' => $this->t('Consent Scope'),
      '#default_value' => $this->config('clickioconsent.settings')->get('scope') ?? 'eu',
      '#description' => $this->t('This setting defines the scope of default consent configurations. Choose <strong>"Only EEA, UK and CH users"</strong> to apply strict <strong>"denied"</strong> defaults only to users in the EEA, UK and CH, while users in other regions will have a general default of <strong>"granted"</strong>. Select <strong>"All users (global)"</strong> to apply <strong>"denied"</strong> defaults universally. Make sure this setting matches the equivalent setting in the Clickio CMP interface to avoid any conflicts.'),
      '#options' =>  [ 'eu' => 'Only EEA, UK and CH users', 'all' => 'All users (global)' ],
    );

    $form['range']['wait'] = array(
      '#type' => 'number',
      '#title' => $this->t('Wait for update (ms)'),
      '#default_value' => $this->config('clickioconsent.settings')->get('wait') ?? 1500,
      '#description' => $this->t("This setting determines how long, in milliseconds, the Google tags should wait before attempting to update the user's consent state. This delay provides a buffer to ensure that any necessary consent changes are effectively captured, helping maintain alignment with user preferences."),
    );


    $form['range']['redact'] = array(
      '#type' => 'checkbox',
      '#title' => $this->t('Redact ads data'),
      '#default_value' => $this->config('clickioconsent.settings')->get('redact') ?? TRUE,
      '#description' => $this->t('When ad_storage is denied, ad click identifiers sent in network requests by Google Ads and Floodlight tags will be redacted. <a href="https://developers.google.com/tag-platform/security/guides/consent?consentmode=advanced#redact_ads_data" target="_blank">Read more</a>'),
    );

    $form['range']['passthrough'] = array(
      '#type' => 'checkbox',
      '#title' => $this->t('Enable URL passthrough'),
      '#default_value' => $this->config('clickioconsent.settings')->get('passthrough') ?? FALSE,
      '#description' => $this->t('Pass through ad click, client ID, and session ID information in URLs. <a href="https://developers.google.com/tag-platform/security/guides/consent?consentmode=advanced#passthroughs" target="_blank">Read more</a>'),
    );
//---- ^

    $form['clickioconsent_enabled'] = array(
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Clickio CMP'),
      '#default_value' => $this->config('clickioconsent.settings')->get('clickioconsent_enabled') ?? FALSE,
      '#description' => $this->t('Automatically include Clickio CMP code to the page. Warning! Do not use this option if you have already installed the main code directly. <a href="https://docs.clickio.com/link/426" target="_blank">Read more</a>'),
    );

    $form['tcf_stab_enabled'] = array(
      '#type' => 'checkbox',
      '#title' => $this->t('Include TCF Stub'),
      '#default_value' => $this->config('clickioconsent.settings')->get('tcf_stab_enabled') ?? FALSE,
      '#description' => $this->t('Installing the TCF stub can improve the reliability of your TCF implementation. In addition, if the "Allow Consent Mode to read TCF signals" setting is enabled, Google tags are able to read specific flags using TCF signals (<a href="https://docs.clickio.com/link/427#bkmrk-5.1.-tcf-mode" target="_blank">read more</a>).'),
    );


    $form['#attached']['library'][] = 'clickioconsent/settings';

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $settings = $this->config('clickioconsent.settings');
    $settings->set('site_id', $form_state->getValue('site_id'));
    $settings->set('consent_enabled', $form_state->getValue('consent_enabled'));
    $settings->set('scope', $form_state->getValue('scope'));
    $settings->set('wait', $form_state->getValue('wait'));
    $settings->set('redact', $form_state->getValue('redact'));
    $settings->set('passthrough', $form_state->getValue('passthrough'));
    $settings->set('clickioconsent_enabled', $form_state->getValue('clickioconsent_enabled'));
    $settings->set('tcf_stab_enabled', $form_state->getValue('tcf_stab_enabled'));
    $settings->save();
    parent::submitForm($form, $form_state);
  }

}

==> clickioconsent-1.0.5.tar.gz: clickioconsent/src/Form/ClickioCmpForm.php <==
<?php

namespace Drupal\clickioconsent\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines the configuration export form.
 */
class ClickioCmpForm extends ConfigFormBase {

  /**
   * The entity_type.bundle.info service.
   *
   * @var \Drupal\Core\Entity\EntityTypeBundleInfoInterface
   */
  protected $entityTypeBundleInfo;

  /**
   * The state service.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected $state;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    /**
     * @var \Drupal\clickioconsent\Form\ClickioCmpForm
     */
    $instance = parent::create($container);
    $instance->entityTypeBundleInfo = $container->get('entity_type.bundle.info');
//    $instance->metatagManager = $container->get('metatag.manager');
    $instance->state = $container->get('state');
//    $instance->tagPluginManager = $container->get('plugin.manager.metatag.tag');

    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'clickioconsent_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['clickioconsent.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    if ($this->state->get('system.maintenance_mode')) {
      $this->messenger()->addMessage($this->t('Please note that while the site is in maintenance mode none of the usual meta tags will be output.'));
    }


    $form['site_id'] = array(
      '#type' => 'number',
      '#title' => $this->t('Clickio Site ID'),
      '#default_value' => $this->config('clickioconsent.settings')->get('site_id') ?? '',
      '#description' => $this->t('Place your <a href="https://docs.clickio.com/link/427#bkmrk-access-the-template%3A" target="_blank">Site ID from Clickio platform</a>.'),
    );

    $form['consent_enabled'] = array(
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Consent Mode support'),
      '#default_value' => $this->config('clickioconsent.settings')->get('consent_enabled') ?? FALSE,
      '#description' => $this->t('Allows this GTM template to automatically set <strong>default</strong> consent states and <strong>update</strong> consent states based on previous decisions made through Clickio CMP. This option functions correctly only when the "Consent Mode support" feature is activated in the Clickio Consent settings UI. Ensure this feature is enabled to properly synchronize consent management across your site. <a href="https://docs.clickio.com/link/427" target="_blank">Read more</a>'),
    );

    $form['range'] = array(
       '#type' => 'fieldset',
       '#collapsible' => TRUE,
       '#attributes' => [ 'style' => ['display:'.($this->config('clickioconsent.settings')->get('consent_enabled') === 0 ?'none':'block') ] ],
    );
//---- V
    $form['range']['scope'] = array(
      '#type' => 'radios',
      '#title' => $this->t('Consent Scope'),
      '#default_value' => $this->config('clickioconsent.settings')->get('scope') ?? 'eu',
      '#description' => $this->t('This setting defines the scope of default consent configurations. Choose <strong>"Only EEA, UK and CH users"</strong> to apply strict <strong>"denied"</strong> defaults only to users in the EEA, UK and CH, while users in other regions will have a general default of <strong>"granted"</strong>. Select <strong>"All users (global)"</strong> to apply <strong>"denied"</strong> defaults universally. Make sure this setting matches the equivalent setting in the Clickio CMP interface to avoid any conflicts.'),
      '#options' =>  [ 'eu' => 'Only EEA, UK and CH users', 'all' => 'All users (global)' ],
    );

    $form['range']['wait'] = array(
      '#type' => 'number',
      '#title' => $this->t('Wait for update (ms)'),
      '#default_value' => $this->config('clickioconsent.settings')->get('wait') ?? 1500,
      '#description' => $this->t("This setting determines how long, in milliseconds, the Google tags should wait before attempting to update the user's consent state. This delay provides a buffer to ensure that any necessary consent changes are effectively captured, helping maintain alignment with user preferences."),
    );


    $form['range']['redact'] = array(
      '#type' => 'checkbox',
      '#title' => $this->t('Redact ads data'),
      '#default_value' => $this->config('clickioconsent.settings')->get('redact') ?? TRUE,
      '#description' => $this->t('When ad_storage is denied, ad click identifiers sent in network requests by Google Ads and Floodlight tags will be redacted. <a href="https://developers.google.com/tag-platform/security/guides/consent?consentmode=advanced#redact_ads_data" target="_blank">Read more</a>'),
    );

    $form['range']['passthrough'] = array(
      '#type' => 'checkbox',
      '#title' => $this->t('Enable URL passthrough'),
      '#default_value' => $this->config('clickioconsent.settings')->get('passthrough') ?? FALSE,
      '#description' => $this->t('Pass through ad click, client ID, and session ID information in URLs. <a href="https://developers.google.com/tag-platform/security/guides/consent?consentmode=advanced#passthroughs" target="_blank">Read more</a>'),
    );
//---- ^

    $form['clickioconsent_enabled'] = array(
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Clickio CMP'),
      '#default_value' => $this->config('clickioconsent.settings')->get('clickioconsent_enabled') ?? FALSE,
      '#description' => $this->t('Automatically include Clickio CMP code to the page. Warning! Do not use this option if you have already installed the main code directly. <a href="https://docs.clickio.com/link/426" target="_blank">Read more</a>'),
    );

    $form['tcf_stab_enabled'] = array(
      '#type' => 'checkbox',
      '#title' => $this->t('Include TCF Stub'),
      '#default_value' => $this->config('clickioconsent.settings')->get('tcf_stab_enabled') ?? FALSE,
      '#description' => $this->t('Installing the TCF stub can improve the reliability of your TCF implementation. In addition, if the "Allow Consent Mode to read TCF signals" setting is enabled, Google tags are able to read specific flags using TCF signals (<a href="https://docs.clickio.com/link/427#bkmrk-5.1.-tcf-mode" target="_blank">read more</a>).'),
    );


    $form['#attached']['library'][] = 'clickioconsent/settings';

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $settings = $this->config('clickioconsent.settings');
    $settings->set('site_id', $form_state->getValue('site_id'));
    $settings->set('consent_enabled', $form_state->getValue('consent_enabled'));
    $settings->set('scope', $form_state->getValue('scope'));
    $settings->set('wait', $form_state->getValue('wait'));
    $settings->set('redact', $form_state->getValue('redact'));
    $settings->set('passthrough', $form_state->getValue('passthrough'));
    $settings->set('clickioconsent_enabled', $form_state->getValue('clickioconsent_enabled'));
    $settings->set('tcf_stab_enabled', $form_state->getValue('tcf_stab_enabled'));
    $settings->save();
    parent::submitForm($form, $form_state);
  }

}
